@@ -111,6 +111,7 @@ class CAM(object):
         <br>Has Free GPU\t: "bash('nvidia-smi').count(' 0MiB /') > 2"
         <br>Slurm job count\t: "int(bash('squeue -h -t pending,running -r | wc -l')) < 4"
         <br>Slurm node count\t: "bash('squeue').count('ltl-gpu')<4"
+        <br>`cam worker "some start condition" prefix suffix` will add prefix and suffix to the command.
         """
         log_info("Worker started. Listening to {0} ...".format(self._conf['server']))
         worker_start_time = get_time()
@@ -164,9 +165,12 @@ class CAM(object):
             self._redis.rpush("pending", json.dumps([cnt, get_time(), cmd, "Pending"]))
         self._redis.set('jobid', cnt + 1)
 
-    def ls(self, type = None):
+    def ls(self, type = None, maxwidth = None):
         """
         Show the status of all tasks.
+        <br>`cam ls` will list both tasks and workers information.
+        <br>`cam ls worker 30` will list all workers wile each column has at most 30 chars.
+        <br>`cam ls task 30` will list all tasks wile each column has at most 30 chars.
         """
         now = datetime.datetime.now()
         if type is None or type == "task":
@@ -179,6 +183,8 @@ class CAM(object):
                 data = json.loads(res[i].decode("utf-8"))
                 st = datetime.datetime.fromisoformat(data[1])
                 data[1] = str(now - st).split('.')[0]
+                if maxwidth is not None:
+                    data[2] = data[2][:maxwidth]
                 nres.append(data)
             print(table_list(nres, headers = ["ID", "Time", "Command", "Host/PID"]))
             print()
@@ -189,6 +195,8 @@ class CAM(object):
                 dt = json.loads(workers[w].decode("utf-8"))
                 st = datetime.datetime.fromisoformat(dt[0])
                 lst = [w, str(now - st).split('.')[0]] + dt[1:]
+                if maxwidth is not None and len(lst) > 3:
+                    lst[3] = lst[3][:maxwidth]
                 info.append(lst)    
             print(table_list(info, headers = ["Worker/PID", "Up Time", "Status", "cond", "prefix", "suffix"]))
 
